==> 1.0.90+1.tar.gz: lib/props/UikButtonProps.dart <==
import 'dart:convert';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/uik_button_props.g.dart';
import 'package:ui_sdk/props/UikAction.dart';
import 'package:ui_sdk/props/UikAction.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'WidgetProps.dart';

@JsonSerializable()
class UikButtonProps extends WidgetProps {
  late String id = "123";
  Widget? text;
  Widget? icon;
  late Color borderColor = Color(0xFFFFD60A);
  late Color backgroundColor = Color(0xFFFFD60A);
  late double? elevation = 0.0;
  late double? borderRadius = 0.0;
  late double width = 0.0;
  late double? height = 0.0;
  late double? verticalPadding = 0.0;
  late double? horizontalPadding = 0.0;
  late double leftMargin = 0.0;
  late double rightMargin = 0.0;
  late double topMargin = 0.0;
  late double bottomMargin = 0.0;
  late UikAction action;

  UikButtonProps();

  factory UikButtonProps.fromJson(Map<String, dynamic> json) =>
      $UikButtonPropsFromJson(json);

  @override
  String toString() {
    return jsonEncode(this);
  }

  UikButtonProps mockWidget() {
    return UikButtonProps.fromJson({
      "id": "checkoutButton",
      "width": "360.0",
      "height": "64.0",
      "leftMargin": "16.0",
      "rightMargin": "16.0",
      "topMargin": "16.0",
      "bottomMargin": "16.0",
      "borderRadius": "6.0",
      "backgroundColor": "0xFFFEE440",
      "text": {
        "id": "text",
        "text": "Checkout",
        "size": "16.0",
        "action": {
          "tap": {
            "type": "UIK_OPEN_WEB",
            "data": {
              "url": "https://sylhetmirror.com/2022/04/03/tesla-delivers-over-1-million-electric-cars-over-past-year/"
            }
          }
        }
      },
      "action": {
        "tap": {
          "type": "OPEN_CHECKOUT",
          "data": {
            "url": "https://www.tesla.com/"
          }
        }
      }
    });
  }


}

==> 1.0.104+1.tar.gz: lib/props/UikButtonProps.dart <==
import 'dart:convert';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/uik_button_props.g.dart';
import 'package:ui_sdk/props/UikAction.dart';
import 'package:ui_sdk/props/UikAction.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'WidgetProps.dart';

@JsonSerializable()
class UikButtonProps extends WidgetProps {
  late String id = "123";
  Widget? text;
  Widget? icon;
  late Color borderColor = Color(0xFFFFD60A);
  late Color backgroundColor = Color(0xFFFFD60A);
  late double? elevation = 0.0;
  late double? borderRadius = 0.0;
  late double width = 0.0;
  late double? height = 0.0;
  late double? verticalPadding = 0.0;
  late double? horizontalPadding = 0.0;
  late double leftMargin = 0.0;
  late double rightMargin = 0.0;
  late double topMargin = 0.0;
  late double bottomMargin = 0.0;
  late UikAction action;

  UikButtonProps();

  factory UikButtonProps.fromJson(Map<String, dynamic> json) =>
      $UikButtonPropsFromJson(json);

  @override
  String toString() {
    return jsonEncode(this);
  }

  UikButtonProps mockWidget() {
    return UikButtonProps.fromJson({
      "id": "checkoutButton",
      "width": "360.0",
      "height": "64.0",
      "leftMargin": "16.0",
      "rightMargin": "16.0",
      "topMargin": "16.0",
      "bottomMargin": "16.0",
      "borderRadius": "6.0",
      "backgroundColor": "0xFFFEE440",
      "text": {
        "id": "text",
        "text": "Checkout",
        "size": "16.0",
        "action": {
          "tap": {
            "type": "UIK_OPEN_WEB",
            "data": {
              "url":
                  "https://sylhetmirror.com/2022/04/03/tesla-delivers-over-1-million-electric-cars-over-past-year/"
            }
          }
        }
      },
      "action": {
        "tap": {
          "type": "OPEN_CHECKOUT",
          "data": {"url": "https://www.tesla.com/"}
        }
      }
    });
  }
}
